# coding: utf8
""" 
@ File: __init__.py
@ Editor: PyCharm
@ Author: Austin (From Chengdu.China) https://fairy.host
@ HomePage: https://github.com/AustinFairyland
@ OS: Windows 11 Professional Workstation 22H2
@ CreatedTime: 2023-09-11
"""
from __future__ import annotations

import sys
import warnings
import platform
import asyncio

sys.dont_write_bytecode = True
warnings.filterwarnings("ignore")
if platform.system() == "Windows":
    asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())

from .public import PublicToolsBaseClass
from .datetimes import DateTimeClass
from .exceptional import ReadFilesError
from .exceptional import MySQLSourceError
from .exceptional import ParamsError

__all__ = [
    "PublicToolsBaseClass",
    "DateTimeClass",
    "ReadFilesError",
    "MySQLSourceError",
    "ParamsError",
]



# coding: utf8
""" 
@File: __init__.py
@Editor: PyCharm
@Author: Austin (From Chengdu.China) https://fairy.host
@HomePage: https://github.com/AustinFairyland
@OperatingSystem: Windows 11 Professional Workstation 23H2 Canary Channel
@CreatedTime: 2024-01-07
"""
from __future__ import annotations

import os
import sys
import warnings
import platform
import asyncio

sys.dont_write_bytecode = True
warnings.filterwarnings('ignore')
if platform.system() == 'Windows':
    asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())

import time
import random

name = "austin_module_daily_tools"

from .public import PublicToolsBaseClass
from .public import DateTimeClass
from .public import ParamsError

__all__ = [
    "PublicToolsBaseClass",
    "DateTimeClass",
    "ParamsError",
]



# coding: utf8
"""
@ File: datetimes.py
@ Editor: PyCharm
@ Author: Austin (From Chengdu.China) https://fairy.host
@ HomePage: https://github.com/AustinFairyland
@ OS: Linux Ubunut 22.04.4 Kernel 6.2.0-36-generic 
@ CreatedTime: 2023/11/26
"""
from __future__ import annotations


import sys
import warnings
import platform
import asyncio


sys.dont_write_bytecode = True
warnings.filterwarnings("ignore")
if platform.system() == "Windows":
    asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())


from datetime import datetime
import time
import re

from .exceptional import ParamsError


class DateTimeClass:
    @staticmethod
    def normtimestamp():
        """
        Standard 10-bit timestamps
        @return: 10-bit timestamps: Integer
        """
        return time.time().__int__()

    @staticmethod
    def normdatetime():
        """
        Formatting Date Time : fmt: "%Y-%m-%d %H:%M:%S"
        @return: Fmt datetime: String
        """
        return datetime.now().strftime("%Y-%m-%d %H:%M:%S")

    @staticmethod
    def timestamp_nbit(n: int) -> str:
        """
        n-bit timestamps
        @param n: n-bit: Integer
        @return: n-bit timestamps: String
        """
        if not isinstance(n, int):
            raise TypeError
        timestamp_str = time.time().__str__().replace(".", "")
        if n <= 16:
            result = timestamp_str[:n]
        else:
            result = "".join(
                (
                    timestamp_str,
                    (n - len(timestamp_str)) * "0",
                )
            )
        return result

    @staticmethod
    def timestamp_dt(fmt: str = None) -> int:
        """
        Datetime to timestamps
        @param fmt: At least 14-bits of time and date: String
        @return: Standard 10-bit timestamp: Integer
        """
        if fmt:
            data_string = "".join(re.findall(r"\d+", fmt))
            if data_string.__len__() == 14:
                fmt = "{}-{}-{} {}:{}:{}".format(
                    data_string[:4],
                    data_string[4:6],
                    data_string[6:8],
                    data_string[8:10],
                    data_string[10:12],
                    data_string[12:14],
                )
                results = (
                    datetime.strptime(fmt, "%Y-%m-%d %H:%M:%S").timestamp().__int__()
                )
            else:
                raise ParamsError
        else:
            results = time.time().__int__()
        return results

    @staticmethod
    def datetime_ts(timestamp: int | str = None, fmt: str = "%Y-%m-%d %H:%M:%S"):
        """
        Timestamps to fmt datetime
        @param timestamp: timestamps: Integer | String
        @param fmt: Fmt datetime, default: %Y-%m-%d %H:%M:%S: String
        @return: Fmt datetime: String
        """
        if timestamp:
            results = datetime.fromtimestamp(timestamp).strftime(fmt)
        else:
            results = datetime.now().strftime(fmt)
        return results



# coding: utf8
""" 
@ File: public.py
@ Editor: PyCharm
@ Author: Austin (From Chengdu.China) https://fairy.host
@ HomePage: https://github.com/AustinFairyland
@ OS: Windows 11 Professional Workstation 22H2
@ CreatedTime: 2023-09-11
"""
from __future__ import annotations

import os
import sys
import warnings
import platform
import asyncio

sys.dont_write_bytecode = True
warnings.filterwarnings("ignore")
if platform.system() == "Windows":
    asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())


class PublicToolsBaseClass:
    """公共工具基类"""

    def __init__(self, *args, **kwargs):
        self.__root_path = os.path.abspath(
            os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
        )

    @property
    def root_path(self) -> str:
        return self.__root_path

    @staticmethod
    def obtain_root_path():
        results = os.path.abspath(
            os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
        )
        return results

    @staticmethod
    def api_results():
        results = {"status": "failure", "code": 500, "data": None}
        return results

    @staticmethod
    def data_string():
        results = str()
        return results

    @staticmethod
    def data_integer():
        results = int()
        return results

    @staticmethod
    def data_float():
        results = float()
        return results

    @staticmethod
    def data_boolean():
        results = bool()
        return results

    @staticmethod
    def data_list():
        results = list()
        return results

    @staticmethod
    def data_tuple():
        results = tuple()
        return results

    @staticmethod
    def data_set():
        results = set()
        return results

    @staticmethod
    def data_dict():
        results = dict()
        return results

    @staticmethod
    def data_none():
        return None

    @staticmethod
    def data_byte():
        results = bytes()
        return results

    @staticmethod
    def data_bytearray():
        results = bytearray()
        return results

    @staticmethod
    def data_complex():
        results = complex()
        return results



# coding: utf8
"""
@ File: exceptional.py
@ Editor: PyCharm
@ Author: Austin (From Chengdu.China) https://fairy.host
@ HomePage: https://github.com/AustinFairyland
@ OS: Linux Ubunut 22.04.4 Kernel 6.2.0-36-generic 
@ CreatedTime: 2023/11/25
"""
from __future__ import annotations

import sys
import warnings
import platform
import asyncio

sys.dont_write_bytecode = True
warnings.filterwarnings("ignore")
if platform.system() == "Windows":
    asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())


class ProjectError(Exception):
    pass


class ParamsError(ProjectError):
    pass


class ReadFilesError(ProjectError):
    pass


class MySQLSourceError(ProjectError):
    pass



# coding: utf8
""" 
@File: setup.py
@Editor: PyCharm
@Author: Austin (From Chengdu.China) https://fairy.host
@HomePage: https://github.com/AustinFairyland
@OperatingSystem: Windows 11 Professional Workstation 23H2 Canary Channel
@CreatedTime: 2024-01-07
"""
from __future__ import annotations

import os
import sys
import warnings
import platform
import asyncio

sys.dont_write_bytecode = True
warnings.filterwarnings("ignore")
if platform.system() == "Windows":
    asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())

import time
import random

import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
    
setuptools.setup(
    name="austin-module-daily",
    version="0.0.4",
    # version="0.0.4.20240107_alpha02",
    author="Austin D",
    author_email="fairylandhost@outlook.com",
    description="Austin personally developed Python library.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/AustinFairyland/AustinModulesDaily",
    packages=setuptools.find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "Natural Language :: English",
        "Natural Language :: Chinese (Simplified)",
        "Operating System :: Microsoft :: Windows :: Windows 11",
        "Topic :: Software Development :: Version Control :: Git",
        "License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)"
    ],
    python_requires=">=3.7",
    
)
